@@ -1,4 +1,4 @@
-# copyright 2011-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2011-2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -121,7 +121,7 @@ class AttachToPatchesOp(hook.DataOperationMixIn, hook.LateOperation):
                 patches = self.related_patch(rev)
                 if patches:
                     patch = patches[0]
-                    rev.set_relations(reverse_patch_revision=patch.eid)
+                    rev.cw_set(reverse_patch_revision=patch.eid)
                     for folded in patches[1:]:
                         operation.add_data((repo.eid, folded.eid, rev.eid))
                 elif rev.phase != 'public':
@@ -235,7 +235,10 @@ class PatchLifeCheckOp(hook.DataOperationMixIn, hook.SingleLastOperation):
                 name = (rev.description.splitlines() or [rev.dc_title()])[0]
                 if name != patch.patch_name:
                     patch.cw_set(patch_name=name)
-                if wfable.state != 'pending-review':
+                if wfable.state == 'outdated':
+                    wfable.fire_transition('reopen', u'new version %s'
+                                           % rev.changeset)
+                elif wfable.state == 'reviewed':
                     wfable.fire_transition('ask review', u'new version %s'
                                            % rev.changeset)
             # patch has no visible tip
@@ -367,7 +370,7 @@ class ReviewerSetHook(hook.Hook):
         except RegistryException:
             # view unregistered or unselectable
             return
-        notification.RenderAndSendNotificationView(self._cw, view=view)
+        notification.notify_on_commit(self._cw, view=view)
         # ensure user is in the nosy-list
         self._cw.execute('SET P nosy_list U '
                          'WHERE P eid %(p)s, U eid %(u)s, NOT P nosy_list U',
