@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# copyright 2011-2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2011-2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -134,9 +134,9 @@ class PatchLifeCycleTC(HgHelper):
         patch = revs[0].reverse_patch_revision[0]
         self.assertEqual('Initial jungle content', patch.patch_name)
         patch_state = patch.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch_state)
+        self.assertEqual('in-progress', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review'], wf_history)
+        self.assertEqual([], wf_history)
 
         # turn the changeset public
         hg('phase', '--public', '0')
@@ -146,7 +146,7 @@ class PatchLifeCycleTC(HgHelper):
         patch_state = patch.cw_adapt_to('IWorkflowable').state
         self.assertEqual('applied', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review', 'applied'], wf_history)
+        self.assertEqual(['applied'], wf_history)
 
     def test_draft_publishing(self):
         self.test_root_publishing()
@@ -174,9 +174,9 @@ class PatchLifeCycleTC(HgHelper):
         self.assertNotEqual(oldpatch.eid, patch.eid)
         self.assertEqual('couple of elephants', patch.patch_name)
         patch_state = patch.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch_state)
+        self.assertEqual('in-progress', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review'], wf_history)
+        self.assertEqual([], wf_history)
         # old patch is unchanged
         oldpatch_state = oldpatch.cw_adapt_to('IWorkflowable').state
         self.assertEqual('applied', oldpatch_state)
@@ -189,7 +189,7 @@ class PatchLifeCycleTC(HgHelper):
         patch_state = patch.cw_adapt_to('IWorkflowable').state
         self.assertEqual('applied', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review', 'applied'], wf_history)
+        self.assertEqual(['applied'], wf_history)
 
     def test_empty_desc(self):
         self.test_root_publishing()
@@ -222,9 +222,9 @@ class PatchLifeCycleTC(HgHelper):
         self.assertNotEqual(oldpatch.eid, patch.eid)
         self.assertEqual('XXX', patch.patch_name)
         patch_state = patch.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch_state)
+        self.assertEqual('in-progress', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review'], wf_history)
+        self.assertEqual([], wf_history)
 
         # Fix changeset content and description
         path = osp.join(self.tmprepo, 'jungle')
@@ -241,9 +241,9 @@ class PatchLifeCycleTC(HgHelper):
         newpatch = rev.reverse_patch_revision[0]
         self.assertEqual(patch.eid, newpatch.eid)
         patch_state = patch.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch_state)
+        self.assertEqual('in-progress', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review'], wf_history)
+        self.assertEqual([], wf_history)
         self.assertEqual('first child', patch.patch_name)
 
         # yet another successor. A public one
@@ -255,7 +255,7 @@ class PatchLifeCycleTC(HgHelper):
         patch_state = patch.cw_adapt_to('IWorkflowable').state
         self.assertEqual('applied', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review', 'applied'], wf_history)
+        self.assertEqual(['applied'], wf_history)
         self.assertEqual(3, len(patch.patch_revision))
 
 
@@ -281,9 +281,9 @@ class PatchLifeCycleTC(HgHelper):
         self.assertNotEqual(oldpatch.eid, patch.eid)
         self.assertEqual('seocnd child', patch.patch_name)
         patch_state = patch.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch_state)
+        self.assertEqual('in-progress', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review'], wf_history)
+        self.assertEqual([], wf_history)
 
         # amend the patch
         hg('commit', '--amend', '-m', 'second child')
@@ -291,10 +291,10 @@ class PatchLifeCycleTC(HgHelper):
         # test that patch has two revisions
         patch.cw_clear_all_caches()
         patch_state = patch.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch_state)
+        self.assertEqual('in-progress', patch_state)
         self.assertEqual(2, len(patch.patch_revision))
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review'], wf_history)
+        self.assertEqual([], wf_history)
 
         prec = self.get_id('.')
         hg('up', '.^')
@@ -305,7 +305,7 @@ class PatchLifeCycleTC(HgHelper):
         patch_state = patch.cw_adapt_to('IWorkflowable').state
         self.assertEqual('rejected', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review', 'rejected'], wf_history)
+        self.assertEqual(['rejected'], wf_history)
         self.assertEqual(2, len(patch.patch_revision))
 
     def test_zombie(self):
@@ -330,9 +330,9 @@ class PatchLifeCycleTC(HgHelper):
         self.assertNotEqual(oldpatch.eid, patch.eid)
         self.assertEqual('second child', patch.patch_name)
         patch_state = patch.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch_state)
+        self.assertEqual('in-progress', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review'], wf_history)
+        self.assertEqual([], wf_history)
 
         # have a successor out of the repo
         path = osp.join(self.tmprepo, 'jungle')
@@ -350,7 +350,7 @@ class PatchLifeCycleTC(HgHelper):
         patch_state = patch.cw_adapt_to('IWorkflowable').state
         self.assertEqual('outdated', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review', 'outdated'], wf_history)
+        self.assertEqual(['outdated'], wf_history)
         self.assertEqual(1, len(patch.patch_revision))
 
         # make the successor visible again
@@ -359,10 +359,9 @@ class PatchLifeCycleTC(HgHelper):
         # test should be alive again
         patch.cw_clear_all_caches()
         patch_state = patch.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch_state)
+        self.assertEqual('in-progress', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review', 'outdated', 'pending-review'],
-                         wf_history)
+        self.assertEqual(['outdated', 'in-progress'], wf_history)
         self.assertEqual(2, len(patch.patch_revision))
 
     def test_delete_revision(self):
@@ -409,9 +408,9 @@ class PatchLifeCycleTC(HgHelper):
         self.assertNotEqual(oldpatch.eid, patch.eid)
         self.assertEqual('Moar children', patch.patch_name)
         patch_state = patch.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch_state)
+        self.assertEqual('in-progress', patch_state)
         wf_history = self.get_wf_history(patch)
-        self.assertEqual(['pending-review'], wf_history)
+        self.assertEqual([], wf_history)
 
         # split them in two
         hg('up', '.^')
@@ -439,13 +438,13 @@ class PatchLifeCycleTC(HgHelper):
         self.assertEqual(2, len(patch1.patch_revision))
         self.assertEqual(1, len(patch2.patch_revision))
         patch1_state = patch1.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch1_state)
+        self.assertEqual('in-progress', patch1_state)
         patch1_wf_history = self.get_wf_history(patch1)
-        self.assertEqual(['pending-review'], patch1_wf_history)
+        self.assertEqual([], patch1_wf_history)
         patch2_state = patch1.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch2_state)
+        self.assertEqual('in-progress', patch2_state)
         patch2_wf_history = self.get_wf_history(patch2)
-        self.assertEqual(['pending-review'], patch2_wf_history)
+        self.assertEqual([], patch2_wf_history)
 
     def test_fold(self):
         self.test_root_publishing()
@@ -493,13 +492,13 @@ class PatchLifeCycleTC(HgHelper):
         self.assertEqual(2, len(patch1.patch_revision))
         self.assertEqual(1, len(patch2.patch_revision))
         patch1_state = patch1.cw_adapt_to('IWorkflowable').state
-        self.assertEqual('pending-review', patch1_state)
+        self.assertEqual('in-progress', patch1_state)
         wf1_history = self.get_wf_history(patch1)
-        self.assertEqual(['pending-review'], wf1_history)
+        self.assertEqual([], wf1_history)
         patch2_state = patch2.cw_adapt_to('IWorkflowable').state
         self.assertEqual('folded', patch2_state)
         wf2_history = self.get_wf_history(patch2)
-        self.assertEqual(['pending-review', 'folded'], wf2_history)
+        self.assertEqual(['folded'], wf2_history)
 
     def test_late_obsolete(self):
         hg = self.call_hg
@@ -610,6 +609,9 @@ class PatchNotificationTC(CubicWebTC):
         assert rev.description == 'Add more elephants children'
         patch = rev.reverse_patch_revision[0]
         assert patch.patch_name == 'Add more elephants children'
+        patch.cw_adapt_to('IWorkflowable').fire_transition('ask review')
+        self.commit()
+        patch.cw_clear_all_caches()
         self.assertEqual(1, len(patch.patch_reviewer))
         reviewer = patch.patch_reviewer[0]
         self.assertIn(reviewer.login, ('Babar', 'Basile'))
@@ -617,7 +619,7 @@ class PatchNotificationTC(CubicWebTC):
         self.assertEqual(2, len(nosyed))
         self.assertIn(reviewer.login, nosyed)
 
-        assert not MAILBOX # dunno why this is empty but it is
+        MAILBOX[:] = []
         patch.cw_adapt_to('IWorkflowable').fire_transition('ask rework',
                                                            u'coin coin')
         session.commit(free_cnxset=False)
@@ -727,17 +729,22 @@ class PatchNotificationTC(CubicWebTC):
                               'url: http://testing.fr/cubicweb/task/%i' % task.eid)
 
     def test_nonascii(self):
+        self.assertEqual(0, len(MAILBOX))
         session = self.session
         rql = 'Any R ORDERBY R DESC WHERE R is Revision'
         rev = session.execute(rql).get_entity(0, 0)
         patch = rev.reverse_patch_revision[0]
-        patch.cw_adapt_to('IWorkflowable').fire_transition('ask rework',
-                                                           u'coin coin')
+        self.assertEqual(0, len(MAILBOX))
+        patch_flow = patch.cw_adapt_to('IWorkflowable')
+        patch_flow.fire_transition('ask review', u'beep beep')
         session.commit(free_cnxset=False)
-        self.assertEqual(2, len(MAILBOX))
+        self.assertEqual(3, len(MAILBOX))
+        patch_flow.fire_transition('ask rework', u'coin coin')
+        session.commit(free_cnxset=False)
+        self.assertEqual(5, len(MAILBOX))
 
         MAILBOX[:] = []
-        # patch are only send on ask review, so we reask for review
+        # emails are only sent on ask review, so we ask again for review
         patch.cw_adapt_to('IWorkflowable').fire_transition('ask review',
                                                            u'coin coin')
         session.commit(free_cnxset=False)
