@@ -1,4 +1,4 @@
-# copyright 2011-2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2011-2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -224,8 +224,8 @@ class DetectRebaseTC(HgHelper):
         old = self.all_revs()[rev]
         patch = old.reverse_patch_revision[0]
         iwf = patch.cw_adapt_to('IWorkflowable')
-        # ensure it's in pending-review state
-        self.assertEqual('pending-review', iwf.state)
+        # ensure it's in in-progress state
+        self.assertEqual('in-progress', iwf.state)
         # transition to accept
         iwf.fire_transition('accept')
         patch.cw_clear_all_caches()
